summaryrefslogtreecommitdiffstats
path: root/juk/k3bexporter.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/k3bexporter.h')
-rw-r--r--juk/k3bexporter.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/juk/k3bexporter.h b/juk/k3bexporter.h
index 922694a1..a6b1c27f 100644
--- a/juk/k3bexporter.h
+++ b/juk/k3bexporter.h
@@ -36,11 +36,11 @@ public:
K3bExporter(Playlist *parent = 0);
/**
* Returns a KAction that can be used to invoke the export.
*
* @return action used to start the export.
*/
- virtual KAction *action();
+ virtual TDEAction *action();
Playlist *playlist() const { return m_parent; }
void setPlaylist(Playlist *playlist) { m_parent = playlist; }
@@ -82,7 +82,7 @@ class K3bPlaylistExporter : public K3bExporter
public:
K3bPlaylistExporter(PlaylistBox *parent = 0);
- virtual KAction *action();
+ virtual TDEAction *action();
private slots:
void slotExport();
@@ -36,11 +36,11 @@ public:
K3bExporter(Playlist *parent = 0);
/**
- * Returns a KAction that can be used to invoke the export.
+ * Returns a TDEAction that can be used to invoke the export.
*
* @return action used to start the export.